@@ -2,10 +2,10 @@ context("get_dbkey")
 
 test_that("get_dbkey fails well", {
   skip_on_cran()
-  
-  expect_error(get_dbkey(stationid = "S152%", category = "SW"),
+
+  expect_error(get_dbkey(stationid = "S152%", category = "GW"),
     "No dbkeys found")
-  
+
 })
 
 test_that("get_dbkey works", {
@@ -16,10 +16,10 @@ test_that("get_dbkey works", {
          recorder = "TROL", agency = "WMD", detail.level = "full"))
   expect_is(invisible(res), "data.frame")
   expect_equal(nrow(res), 1)
-  
+
   res <- get_dbkey(stationid = c("MBTS", "JBTS"), category = "WEATHER",
          param = "WNDS", freq = "DA", detail.level = "dbkey")
   expect_equal(length(res), 2)
-  
+
 })
 
